@@ -37,6 +37,7 @@
 #' library(dplyr)
 #' library(timetk)
 #' library(modeltime)
+#' library(earth)
 #'
 #' data <- AirPassengers %>%
 #'   ts_to_tbl() %>%
@@ -127,7 +128,7 @@ ts_auto_mars <- function(.data, .date_col, .value_col, .formula, .rsamp_obj,
 
     rec_obj <- rec_obj %>%
         timetk::step_timeseries_signature({{date_col_var_expr}}) %>%
-        timetk::step_holiday_signature({{date_col_var_expr}}) %>%
+        #timetk::step_holiday_signature({{date_col_var_expr}}) %>%
         recipes::step_novel(recipes::all_nominal_predictors()) %>%
         recipes::step_mutate_at(tidyselect::vars_select_helpers$where(is.character)
                                 , fn = ~ as.factor(.)) %>%
@@ -263,5 +264,5 @@ ts_auto_mars <- function(.data, .date_col, .value_col, .formula, .rsamp_obj,
     attr(output, ".parsnip_engine") <- "earth"
     attr(output, ".function_family") <- "boilerplate"
 
-    return(invisible(output))
+    return(output)
 }
